@@ -1,12 +1,9 @@
 package e2e
 
 import (
-	"fmt"
 	"testing"
 
-	olm "github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
-	"github.com/operator-framework/operator-marketplace/pkg/apis"
-	v1 "github.com/operator-framework/operator-marketplace/pkg/apis/operators/v1"
+	olm "github.com/operator-framework/operator-marketplace/pkg/apis/olm/v1alpha1"
 	"github.com/operator-framework/operator-marketplace/test/helpers"
 	"github.com/operator-framework/operator-marketplace/test/testgroups"
 	"github.com/operator-framework/operator-sdk/pkg/test"
@@ -26,25 +23,12 @@ func TestMarketplace(t *testing.T) {
 	if isConfigAPIPresent, _ := helpers.EnsureConfigAPIIsAvailable(); isConfigAPIPresent == true {
 		t.Run("cluster-operator-status-test-group", testgroups.ClusterOperatorTestGroup)
 	}
-	t.Run("opsrc-test-group", testgroups.OpSrcTestGroup)
 	t.Run("no-setup-test-group", testgroups.NoSetupTestGroup)
 }
 
 // initTestingFramework adds the marketplace OperatorSource and CatalogSourceConfig types as well as the
 // olm CatalogSource type to the framework scheme.
 func initTestingFramework(t *testing.T) {
-	// Add marketplace types to test framework scheme.
-	operatorSource := &v1.OperatorSource{
-		TypeMeta: metav1.TypeMeta{
-			Kind: v1.OperatorSourceKind,
-			APIVersion: fmt.Sprintf("%s/%s",
-				v1.SchemeGroupVersion.Group, v1.SchemeGroupVersion.Version),
-		},
-	}
-	err := test.AddToFrameworkScheme(apis.AddToScheme, operatorSource)
-	if err != nil {
-		t.Fatalf("failed to add OperatorSource custom resource scheme to framework: %v", err)
-	}
 	// Add (olm) CatalogSources to framework scheme.
 	catalogSource := &olm.CatalogSource{
 		TypeMeta: metav1.TypeMeta{
@@ -52,7 +36,7 @@ func initTestingFramework(t *testing.T) {
 			APIVersion: olm.CatalogSourceCRDAPIVersion,
 		},
 	}
-	err = test.AddToFrameworkScheme(olm.AddToScheme, catalogSource)
+	err := test.AddToFrameworkScheme(olm.AddToScheme, catalogSource)
 	if err != nil {
 		t.Fatalf("failed to add CatalogSource custom resource scheme to framework: %v", err)
 	}
